@@ -2,7 +2,7 @@
 ## R source file
 ## This file is part of rgl
 ##
-## $Id: zzz.R 493 2006-07-31 17:21:03Z dmurdoch $
+## $Id: zzz.R 532 2006-12-08 14:25:42Z dmurdoch $
 ##
 
 ##
@@ -17,26 +17,26 @@
 .onLoad <- function(lib, pkg)
 {
   # OS-specific 
-  
+  initValue <- 0  
+
   if ( .Platform$OS.type == "unix" ) {
     unixos <- system("uname",intern=TRUE)
     if ( unixos == "Darwin" ) {
       # For MacOS X we have to remove /usr/X11R6/lib from the DYLD_LIBRARY_PATH
       # because it would override Apple's OpenGL framework
-      Sys.putenv("DYLD_LIBRARY_PATH"=gsub("/usr/X11R6/lib","",Sys.getenv("DYLD_LIBRARY_PATH")))      
+      Sys.putenv("DYLD_LIBRARY_PATH"=gsub("/usr/X11R6/lib","",Sys.getenv("DYLD_LIBRARY_PATH")))
+      initValue <- as.integer(.Platform$GUI == "AQUA")
     }
   } 
   
-  mdiHandle <- 0
-  
   if ( .Platform$OS.type == "windows" ) {
-    if ( getWindowsHandle("Frame") ) mdiHandle <- getWindowsHandle("Console")
+    if ( getWindowsHandle("Frame") ) initValue <- getWindowsHandle("Console")
   } 
   
   	
   ret <- .C( "rgl_init", 
     success=FALSE ,
-    as.integer(mdiHandle),
+    as.integer(initValue),
     PACKAGE="rgl"
   )
   
