@@ -250,8 +250,10 @@ OSStatus OSXWindowImpl::windowHandler(EventHandlerCallRef next, EventRef e) {
             {
               aglUpdateContext(mGLContext);
               GetWindowBounds(mWindowRef,kWindowContentRgn,&mRect);
-              if (window)
+              if (window) {
                 window->resize( mRect.right - mRect.left, mRect.bottom - mRect.top );
+                update();
+		      }
             }
             break; 
         }
@@ -349,6 +351,12 @@ WindowImpl* OSXGUIFactory::createWindowImpl(Window* window)
   return new OSXWindowImpl(window);
 }
 // ---------------------------------------------------------------------------
+extern int gInitValue;
+bool OSXGUIFactory::hasEventLoop()
+{
+  return gInitValue != 0;
+}
+// ---------------------------------------------------------------------------
 } // namespace gui
 // ---------------------------------------------------------------------------
 #endif // RGL_CARBON
