@@ -3,7 +3,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: win32gui.cpp 497 2006-08-03 18:18:19Z dmurdoch $
+// $Id: win32gui.cpp 532 2006-12-08 14:25:42Z dmurdoch $
 
 #include "win32gui.hpp"
 
@@ -14,7 +14,7 @@
 // ---------------------------------------------------------------------------
 namespace gui {
 
-extern int     gMDIHandle;
+extern int     gInitValue;
 static WNDPROC gDefWindowProc;
 static HWND    gMDIClientHandle = 0;
 static HWND    gMDIFrameHandle  = 0;
@@ -182,7 +182,7 @@ void Win32WindowImpl::update()
 
 void Win32WindowImpl::destroy()
 {
-  if (gMDIHandle) SendMessage(gMDIClientHandle, WM_MDIDESTROY, (WPARAM) windowHandle, 0);
+  if (gInitValue) SendMessage(gMDIClientHandle, WM_MDIDESTROY, (WPARAM) windowHandle, 0);
   else DestroyWindow(windowHandle);
 }
 
@@ -302,7 +302,7 @@ LRESULT Win32WindowImpl::processMessage(HWND hwnd, UINT message, WPARAM wParam,
       windowHandle = hwnd;
       initGL();
       initGLBitmapFont(GL_BITMAP_FONT_FIRST_GLYPH, GL_BITMAP_FONT_LAST_GLYPH);
-      if (gMDIHandle) {
+      if (gInitValue) {
         refreshMenu = true;
       }
       break;
@@ -330,7 +330,7 @@ LRESULT Win32WindowImpl::processMessage(HWND hwnd, UINT message, WPARAM wParam,
       break;
     case WM_SIZE:
       window->resize(LOWORD(lParam), HIWORD(lParam));
-      if (gMDIHandle)
+      if (gInitValue)
         return gDefWindowProc(hwnd,message,wParam,lParam);
       else
         break;
@@ -406,7 +406,7 @@ LRESULT CALLBACK Win32WindowImpl::windowProc(HWND hwnd, UINT message, WPARAM wPa
   if (message == WM_CREATE) {
     Win32WindowImpl* windowImpl;
     LPCREATESTRUCT pCreateStruct = reinterpret_cast<LPCREATESTRUCT>(lParam);        
-    if ( gMDIHandle) {          
+    if ( gInitValue) {
       LPMDICREATESTRUCT pMDICreateStruct = reinterpret_cast<LPMDICREATESTRUCT>(pCreateStruct->lpCreateParams);
       windowImpl = reinterpret_cast<Win32WindowImpl*>( pMDICreateStruct->lParam );
     } else {
@@ -451,10 +451,10 @@ ATOM Win32WindowImpl::classAtom = (ATOM) NULL;
 
 Win32GUIFactory::Win32GUIFactory()
 {
-  if (gMDIHandle) {
-    // the handle is given for the console window, so that 
+  if (gInitValue) {
+    // the handle is given for the console window, so that
     // client and frame windows can be derived
-    HWND consoleHandle = reinterpret_cast<HWND>(gMDIHandle);
+    HWND consoleHandle = reinterpret_cast<HWND>(gInitValue);
     gMDIClientHandle = GetParent(consoleHandle);
     gMDIFrameHandle  = GetParent(gMDIClientHandle);
     gDefWindowProc   = &DefMDIChildProc;
@@ -488,7 +488,7 @@ WindowImpl* Win32GUIFactory::createWindowImpl(Window* in_window)
 
   HWND success = 0;
   
-  if (gMDIHandle) {
+  if (gInitValue) {
     success = CreateMDIWindow(
       MAKEINTATOM(Win32WindowImpl::classAtom)
     , in_window->title
